#### load config_file ####
#### read config_file specified when lunching the job. 
args = commandArgs(TRUE)
if (length(args) > 0) {
  configFile_path <- args[1]
} else {
  cat("\n***ERROR: no ConfigFile was provided\n")
}
# If you are running the script manually, load the path as
#configFile_path <- "/esarchive/scratch/jmateu/RUN/run_sensitivity4/config_file.yml"

config         <- yaml::yaml.load_file(configFile_path)
files          <- config$file
nparams        <- config$nparams # model parameters to perform sensitivity
sim_data       <- config$sim_data
image_folder   <- config$image_folder
n_outputs      <- config$n_outputs
repo           <- config$repo
supervariables <- config$supervariables


#### load database ####
# Gather each file of the database. First "nparams" columns are model parameters, the model output in the physical space
all_out <- NULL
for (file in files) {
  # file <- files[1]
	load(file=file)
	all_out <- rbind(all_out,OUT)
}
# all_out = all_out[1:100,]
data_var <- all_out[,(nparams+1):ncol(all_out)]

if (supervariables){
	ndimvar <- 47*73
	sPOC = data_var[ , (0*ndimvar+1):(1*ndimvar) ] +
		data_var[ , (2*ndimvar+1):(3*ndimvar) ] +
		data_var[ , (3*ndimvar+1):(4*ndimvar) ] +
		data_var[ , (4*ndimvar+1):(5*ndimvar) ] 

	lPOC = data_var[ , (1*ndimvar+1):(2*ndimvar) ] +
		data_var[ , (5*ndimvar+1):(6*ndimvar) ]

	tPOC = sPOC+lPOC

	tCHL = data_var[ , (6*ndimvar+1):(7*ndimvar) ] +
		data_var[ , (7*ndimvar+1):(8*ndimvar) ] 

	data <- cbind(sPOC,lPOC,tPOC,tCHL,all_out[,1:nparams])	
}else{
	data <- cbind(data_var,all_out[,1:nparams])
}


## 85% of the sample size
smp_size <- floor(0.85 * nrow(data))

## set the seed to make your partition reproducible
set.seed(13)
train_ind <- sample(seq_len(nrow(data)), size = smp_size)

## split data
data_to_train <-data[train_ind,]
data_to_validate <-data[-train_ind,]

# Remove zero variance columns from the dataset
print(paste("There are", length(which(apply(data_to_train, 2, var) == 0)), "columns with constat/zero values"))
data_to_train <- data_to_train[ , which(apply(data_to_train, 2, var) != 0)]
data_to_validate <- data_to_validate[ , which(apply(data_to_validate, 2, var) != 0)]
if (ncol(data_to_train)!=ncol(data_to_validate)) { print("Warning: constant/zero values") }


# library(viridis)
# var <- 1
# i_row <- 1
# data_for_plot = data_to_train
# plot_field(var, i_row, data_for_plot)

#### save data
saveRDS(data_to_validate,  file = paste0(sim_data,"data_to_validate.RDS"))
saveRDS(data_to_train,     file = paste0(sim_data,"data_to_train.RDS"))
